RefreshablePodFuture<F extends Pod, T> class

Inheritance
Mixed-in types
Available extensions

Constructors

RefreshablePodFuture(F future, T reader(Ref<T>, F future))
RefreshablePodFuture constructor

Properties

future → F
The future Pod.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isKeepAlive → bool
Check if this pod should keep alive
no setterinherited
name → String?
Debug name for this pod
no setterinherited
reader → T Function(Ref<T>, F future)
Reader callback.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncSelect<V>(V cb(T value)) → PodFuture<Pod<AsyncValue<T>>, Future<V>>

Available on Pod<AsyncValue<T>>, provided by the AsyncValuePodExtension extension

Create a derived pod, that transforms a pod's value using the given function cb.
filter(bool predicate(T value)) → PodFuture<Pod<T>, AsyncValue<T>>

Available on Pod<T>, provided by the PodExtension extension

Create a derived pod, that filters the values using the given predicate.
getContext(Node node) → Ref<T>
Used by the container to create a read lifetime. Bit hacky, but allows us to go from dynamic to T.
inherited
keepAlive() → RefreshablePodFuture<F, T>
Prevent the state of this pod from being automatically disposed.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideWithValue(T value, {bool keepAlive = true}) → Override<T>
Create an initial value override, which can be given to a PodScope or PodContainer.
inherited
rawSelect<V>(V cb(AsyncValue<T> value)) → PodFuture<Pod<AsyncValue<T>>, V>

Available on Pod<AsyncValue<T>>, provided by the AsyncValuePodExtension extension

Create a derived pod, that transforms a pod's value using the given function cb.
read(Ref<T> ref) → T
Used by the container to read the pods value.
inherited
refresh(void refresh(Pod pod)) → void
Determines refresh behaviour.
override
select<V>(V cb(T value)) → PodFuture<Pod<AsyncValue<T>>, AsyncValue<V>>

Available on Pod<AsyncValue<T>>, provided by the AsyncValuePodExtension extension

Create a derived pod, that transforms a pod's value using the given function cb.
select<B>(B cb(T value)) → PodNotifier<Pod<T>, B>

Available on Pod<T>, provided by the PodExtension extension

Create a derived pod, that transforms a pod's value using the given function cb.
setName(String name) → RefreshablePodFuture<F, T>
Set a name for debugging
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited